import { Container, interfaces as inversifyTypes } from 'inversify';
import React, { ReactNode } from 'react';
export declare type InjectConfig = Record<string, inversifyTypes.ServiceIdentifier<any>>;
export declare type InjectableProps<T> = {
    [K in keyof T]: inversifyTypes.ServiceIdentifier<any>;
};
interface ProviderProps {
    container: Container;
    children: ReactNode;
}
/**
 * Creates an object that contains a provider component that can be used to pass
 * the container down to child components, and an injector decorator that can be used
 * to inject services into a component.
 */
export declare function createInjection(defaultContainer?: Container): {
    /**
     * The context of the injection.
     */
    context: React.Context<Container | undefined>;
    /**
     * Provides child components with the given container.
     */
    InjectionProvider: {
        new (props: ProviderProps): {
            render(): JSX.Element;
            context: any;
            setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<ProviderProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<ProviderProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<ProviderProps>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<ProviderProps>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<ProviderProps>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<ProviderProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<ProviderProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<ProviderProps>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<ProviderProps>, nextState: Readonly<{}>, nextContext: any): void;
        };
        contextType?: React.Context<any> | undefined;
    };
    /**
     * A wrapped version of the `useInjection` hook that uses the current context.
     */
    useInject<T>(inject: InjectableProps<T>): T;
    /**
     * Returns a function that will create a component that will have the requested services
     * injected as props.
     */
    injectComponent<TInject, TStateMap = {}>(inject: InjectableProps<TInject>, stateMapper?: ((injected: TInject) => TStateMap) | undefined): <TBaseProps>(Comp: React.ComponentType<TBaseProps>) => React.ComponentType<Pick<TBaseProps, Exclude<keyof TBaseProps, Extract<keyof TInject, keyof TBaseProps> | Extract<keyof TStateMap, keyof TBaseProps>>> & {
        container?: Container | undefined;
    }>;
};
export {};
//# sourceMappingURL=create-injection.d.ts.map