"use strict";
var StateTracker_1;
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
let StateTracker = StateTracker_1 = class StateTracker {
    constructor() {
        this.handlers = new Set();
        this.changes = [];
        this.scheduledUpdate = false;
        this.synchronous = false;
    }
    static bindToContainer(container) {
        if (!container.isBound(StateTracker_1)) {
            container.bind(StateTracker_1).toSelf().inSingletonScope();
        }
    }
    enqueueUpdate(update) {
        this.changes.push(update);
        if (!this.synchronous) {
            if (!this.scheduledUpdate) {
                Promise.resolve().then(() => this.handleUpdate());
                this.scheduledUpdate = true;
            }
        }
        else {
            this.handleUpdate();
        }
    }
    handleUpdate() {
        let change;
        let performedChange = false;
        const afters = [];
        while (change = this.changes.shift()) {
            let newState;
            if (typeof change.updater === 'function') {
                newState = change.updater(change.service.state);
            }
            else {
                newState = change.updater;
            }
            if (!newState) {
                continue;
            }
            change.service.state = Object.assign({}, change.service.state, newState);
            performedChange = true;
            if (change.after) {
                afters.push({
                    service: change.service,
                    after: change.after,
                });
            }
        }
        this.scheduledUpdate = false;
        if (performedChange) {
            // Copy all of the handlers to a separate list.
            // This is because when each handler is fired, there's a chance
            // that the component it's from will unbind & rebind, causing the next
            // item in the set to be the same handler.
            const handlersCpy = [];
            this.handlers.forEach(handler => handlersCpy.push(handler));
            // Fire all the handlers.
            for (const handler of handlersCpy) {
                // Since a handler may be unbound as a result of calling
                // the previous handlers, we need to double check that the
                // handler is still bound.
                if (this.handlers.has(handler)) {
                    handler();
                }
            }
            for (const { after, service } of afters) {
                after(service.state);
            }
        }
    }
};
StateTracker = StateTracker_1 = tslib_1.__decorate([
    inversify_1.injectable()
], StateTracker);
exports.StateTracker = StateTracker;
//# sourceMappingURL=state-tracker.js.map