"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const state_tracker_1 = require("./state-tracker");
function useInjection(context, inject) {
    const container = react_1.useContext(context);
    if (!container) {
        throw new Error('No container was provided in context');
    }
    // Use an empty state to allow us to trigger updates on command.
    const [, setTrigger] = react_1.useState({});
    // After render, start listening to state updates.
    // We also need to stop listening on cleanup.
    react_1.useEffect(() => {
        const doUpdate = () => setTrigger({});
        let stateTracker;
        if (container.isBound(state_tracker_1.StateTracker)) {
            stateTracker = container.get(state_tracker_1.StateTracker);
            stateTracker.handlers.add(doUpdate);
        }
        return () => {
            if (stateTracker) {
                stateTracker.handlers.delete(doUpdate);
            }
        };
    });
    // We don't need to re-get the services if the object defining them hasn't changed.
    const services = react_1.useMemo(() => {
        const srv = {};
        for (const key of Object.keys(inject)) {
            srv[key] = container.get(inject[key]);
        }
        return srv;
    }, [inject]);
    return services;
}
exports.useInjection = useInjection;
//# sourceMappingURL=use-injection.js.map